
class date(object):
    def getMailUser(self):
        return 'ar.test@aishu.cn'

    def getMailPass(self):
        return 'Eisoo.com123'